// Copyright (C) 2010 - DIGITEO - Michael Baudin
//
// This file must be used under the terms of the CeCILL.
// This source file is licensed as described in the file COPYING, which
// you should have received as part of this distribution.  The terms
// are also available at
// http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt

function [c,y] = assert_logcond ( x )
  // Computes the condition number of the log function.
  // 
  // Calling Sequence
  //   [c,y] = assert_logcond ( x )
  // 
  // Parameters
  //   x : a n-by-m matrix of doubles
  //   c : a n-by-m matrix of doubles, the condition number
  //   y : a n-by-m, matrix of doubles, the function values
  // 
  // Description
  // Computes the condition number of the exp function.
  // This function is badly conditionned near x=1.
  //
  //<latex>
  //\begin{eqnarray}
  //c(x) = \frac{1}{|\log(x)|}
  //\end{eqnarray}
  //</latex>
  // 
  // Examples
  //  [c,y] = assert_logcond ( 2 )
  //  [c,y] = assert_logcond ( 1 )
  //
  //  // Plot the condition number of log, for positive values.
  //  h = scf();
  //  x = linspace(1.e-10,10,1000);
  //  c = assert_logcond ( x );
  //  plot(x,c)
  //  // Turn on log-scale
  //  h.children.log_flags = "nln"
  //
  // Authors
  // Michael Baudin, DIGITEO, 2010
  //
  
  [lhs,rhs]=argn()
  if ( rhs<>1 ) then
    errmsg = sprintf("%s: Unexpected number of arguments : %d provided while %d are expected.","assert_logcond",rhs,1);
    error(errmsg)
  end
  //
  y = exp(x)
  c = abs(1 ./ log(x) )
endfunction

