// Copyright (C) 2010 - DIGITEO - Michael Baudin
//
// This file must be used under the terms of the CeCILL.
// This source file is licensed as described in the file COPYING, which
// you should have received as part of this distribution.  The terms
// are also available at
// http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt

function [c,y] = assert_sqrtcond ( x )
  // Computes the condition number of the square root function.
  // 
  // Calling Sequence
  //   [c,y] = assert_sqrtcond ( x )
  // 
  // Parameters
  //   x : a n-by-m matrix of doubles
  //   c : a n-by-m matrix of doubles, the condition number
  //   y : a n-by-m, matrix of doubles, the function values
  // 
  // Description
  // Computes the condition number of the square root function.
  // This function has a good condition number.
  //
  //<latex>
  //\begin{eqnarray}
  //c(x) = 1/2
  //\end{eqnarray}
  //</latex>
  // 
  // Examples
  //  [c,y] = assert_sqrtcond ( 2 )
  //
  // Authors
  // Michael Baudin, DIGITEO, 2010
  //
  
  [lhs,rhs]=argn()
  if ( rhs<>1 ) then
    errmsg = sprintf("%s: Unexpected number of arguments : %d provided while %d are expected.","assert_sqrtcond",rhs,1);
    error(errmsg)
  end
  //
  y = sqrt(x)
  c = 1/2
endfunction

