// Copyright (C) 2009 - 2010 - DIGITEO - Michael Baudin
//
// This file must be used under the terms of the CeCILL.
// This source file is licensed as described in the file COPYING, which
// you should have received as part of this distribution.  The terms
// are also available at
// http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt


// <-- JVM NOT MANDATORY -->
// <-- ENGLISH IMPOSED -->

function flag = MY_assert_equal ( computed , expected )
  if computed==expected then
    flag = 1;
  else
    flag = 0;
  end
  if flag <> 1 then pause,end
endfunction

/////////////////////////////////////////////////////////////
function [a,b] = testfun ()
   a = ones(10,10)
   b = zeros(10,10)
endfunction

[t,msg]=assert_benchfun ( testfun );
MY_assert_equal ( size(t) , [10 1] );
MY_assert_equal ( and(t>=0) , %t );
MY_assert_equal ( msg<>"" , %t );
// Let the user customize the message
mprintf("My customize bench message: %s\n",msg);
//
[t,msg]=assert_benchfun ( testfun , [] );
MY_assert_equal ( size(t) , [10 1] );
MY_assert_equal ( and(t>=0) , %t );
MY_assert_equal ( msg<>"" , %t );
//
[t,msg]=assert_benchfun ( testfun , [] );
MY_assert_equal ( size(t) , [10 1] );
MY_assert_equal ( and(t>=0) , %t );
MY_assert_equal ( msg<>"" , %t );
//
[t,msg]=assert_benchfun ( testfun , [] , 2 );
MY_assert_equal ( size(t) , [10 1] );
MY_assert_equal ( and(t>=0) , %t );
MY_assert_equal ( msg<>"" , %t );
//
[t,msg]=assert_benchfun ( testfun , [] , 2 , 15 );
MY_assert_equal ( size(t) , [15 1] );
MY_assert_equal ( and(t>=0) , %t );
MY_assert_equal ( msg<>"" , %t );
//
[t,msg]=assert_benchfun ( testfun , [] , 2 , 15 , "testfun" );
MY_assert_equal ( size(t) , [15 1] );
MY_assert_equal ( and(t>=0) , %t );
MY_assert_equal ( msg<>"" , %t );
//
// Cannot test this: the time varies from call to call
//[t,msg]=assert_benchfun ( testfun , [] , 2 , 15 , "testfun" , %t );
[t,msg]=assert_benchfun ( testfun , [] , 2 , 15 , "testfun" , %f );
MY_assert_equal ( size(t) , [15 1] );
MY_assert_equal ( and(t>=0) , %t );
MY_assert_equal ( msg<>"" , %t );
//
/////////////////////////////////////////////////////////////
// Check that 2 output arguments are actually used
//
function [a,b] = testfun2 ()
   global testing_benchfunargs
   global testing_benchfuncalls
   [lhs,rhs] = argn()
   testing_benchfunargs($+1,1:2) = [lhs,rhs]
   testing_benchfuncalls = testing_benchfuncalls + 1
   a = ones(10,10)
   b = zeros(10,10)
endfunction
global testing_benchfunargs;
global testing_benchfuncalls;
testing_benchfunargs = [];
testing_benchfuncalls = 0;
[t,msg]=assert_benchfun ( testfun2 , [] , 2 );
MY_assert_equal ( size(t) , [10 1] );
MY_assert_equal ( and(t>=0) , %t );
MY_assert_equal ( msg<>"" , %t );
MY_assert_equal ( size(testing_benchfunargs) , [10 2] );
MY_assert_equal ( and(testing_benchfunargs(:,1)==2) , %t );
MY_assert_equal ( and(testing_benchfunargs(:,2)==0) , %t );
MY_assert_equal ( testing_benchfuncalls , 10 );
/////////////////////////////////////////////////////////////
// Check that 2 input argument are actually used
//
function y = testfun3 ( m , n )
   global testing_benchfunargs
   global testing_benchfuncalls
   [lhs,rhs] = argn()
   testing_benchfunargs($+1,1:4) = [lhs,rhs,m,n]
   testing_benchfuncalls = testing_benchfuncalls + 1
   y = ones(m,n)
endfunction
global testing_benchfunargs;
global testing_benchfuncalls;
testing_benchfunargs = [];
testing_benchfuncalls = 0;
[t,msg]=assert_benchfun ( testfun3 , list(12,13));
MY_assert_equal ( size(t) , [10 1] );
MY_assert_equal ( and(t>=0) , %t );
MY_assert_equal ( msg<>"" , %t );
MY_assert_equal ( size(testing_benchfunargs) , [10 4] );
MY_assert_equal ( and(testing_benchfunargs(:,1)==1) , %t );
MY_assert_equal ( and(testing_benchfunargs(:,2)==2) , %t );
MY_assert_equal ( and(testing_benchfunargs(:,3)==12) , %t );
MY_assert_equal ( and(testing_benchfunargs(:,4)==13) , %t );
MY_assert_equal ( testing_benchfuncalls , 10 );
/////////////////////////////////////////////////////////////
// Check that the number of function calls is correct
//
function y = testfun4 ( )
   global testing_benchfuncalls
   testing_benchfuncalls = testing_benchfuncalls + 1
   y = ones(10,10)
endfunction
global testing_benchfuncalls;
testing_benchfuncalls = 0;
[t,msg]=assert_benchfun ( testfun4 , [] , [] , 12 );
MY_assert_equal ( size(t) , [12 1] );
MY_assert_equal ( and(t>=0) , %t );
MY_assert_equal ( msg<>"" , %t );
MY_assert_equal ( testing_benchfuncalls , 12 );

//
/////////////////////////////////////////////////////////////
// Pascal up matrix.
// Column by column version
function c = pascalup_col (n)
   c = eye(n,n)
   c(1,:) = ones(1,n)
   for i = 2:(n-1)
      c(2:i,i+1) = c(1:(i-1),i)+c(2:i,i)
   end
endfunction
//
[t,msg]=assert_benchfun ( pascalup_col , list(100) );
MY_assert_equal ( size(t) , [10 1] );
MY_assert_equal ( and(t>=0) , %t );
MY_assert_equal ( msg<>"" , %t );
//
[t,msg]=assert_benchfun ( pascalup_col , list(100) , 1 );
MY_assert_equal ( size(t) , [10 1] );
MY_assert_equal ( and(t>=0) , %t );
MY_assert_equal ( msg<>"" , %t );
//
[t,msg]=assert_benchfun ( pascalup_col , list(100) , 1 , 10 );
MY_assert_equal ( size(t) , [10 1] );
MY_assert_equal ( and(t>=0) , %t );
MY_assert_equal ( msg<>"" , %t );
//
[t,msg]=assert_benchfun ( pascalup_col , list(100) , 1 , 10 , "pascalup_col" );
MY_assert_equal ( size(t) , [10 1] );
MY_assert_equal ( and(t>=0) , %t );
MY_assert_equal ( msg<>"" , %t );
//
// Cannot test this: the time varies from call to call
//[t,msg]=assert_benchfun ( pascalup_col , list(100) , 1 , 10 , "pascalup_col" , %t );
[t,msg]=assert_benchfun ( pascalup_col , list(100) , 1 , 10 , "pascalup_col" , %f );
MY_assert_equal ( size(t) , [10 1] );
MY_assert_equal ( and(t>=0) , %t );
MY_assert_equal ( msg<>"" , %t );
//
// Test error cases
instr = "assert_benchfun ( pascalup_col )";
ierr=execstr(instr,"errcatch");
MY_assert_equal ( ierr , 10000 );
lerr = lasterror();
MY_assert_equal ( lerr , "assert_benchfun: Failed to run function: Undefined variable: n." );

///////////////////////////////////////////////////////////////
function F = subsets ( E , m )
   // Authors : Chancelier, Pincon
   // compute all the subsets with m elements of the set E
   // (E must be given as a row vector and all its elements
   // must be differents). For sets of numbers.
   n = length(E)
   if m > n then
      F = []
   elseif m == n
      F = E
   elseif m == 1
      F = E';
   else
      F = [];
      for i = 1:n-m+1
         EE = E(i+1:n)
         FF = subsets(EE,m-1)
         mm = size(FF,1)
         F = [F ; E(i)*ones(mm,1),FF]
      end
   end
endfunction

[t,msg]=assert_benchfun ( subsets , list(1:10,3) );
MY_assert_equal ( size(t) , [10 1] );
MY_assert_equal ( and(t>=0) , %t );
MY_assert_equal ( msg<>"" , %t );
//
[t,msg]=assert_benchfun ( subsets , list(1:10,3) , 1 );
MY_assert_equal ( size(t) , [10 1] );
MY_assert_equal ( and(t>=0) , %t );
MY_assert_equal ( msg<>"" , %t );
//
[t,msg]=assert_benchfun ( subsets , list(1:10,3) , 1 , 10 );
MY_assert_equal ( size(t) , [10 1] );
MY_assert_equal ( and(t>=0) , %t );
MY_assert_equal ( msg<>"" , %t );
//
[t,msg]=assert_benchfun ( subsets , list(1:10,3) , 1 , 10 , "subsets" );
MY_assert_equal ( size(t) , [10 1] );
MY_assert_equal ( and(t>=0) , %t );
MY_assert_equal ( msg<>"" , %t );
//
// Cannot test this: the time varies from call to call
//[t,msg]=assert_benchfun ( subsets , list(1:10,3) , 1 , 10 , "subsets" , %t );
[t,msg]=assert_benchfun ( subsets , list(1:10,3) , 1 , 10 , "subsets" , %f );
MY_assert_equal ( size(t) , [10 1] );
MY_assert_equal ( and(t>=0) , %t );
MY_assert_equal ( msg<>"" , %t );
///////////////////////////////////////////////////////////////
// Testing sin
//
[t,msg]=assert_benchfun ( sin , list(ones(100,100)) );
MY_assert_equal ( size(t) , [10 1] );
MY_assert_equal ( and(t>=0) , %t );
MY_assert_equal ( msg<>"" , %t );
//
[t,msg]=assert_benchfun ( sin , list(ones(100,100)) , 1 );
MY_assert_equal ( size(t) , [10 1] );
MY_assert_equal ( and(t>=0) , %t );
MY_assert_equal ( msg<>"" , %t );
//
[t,msg]=assert_benchfun ( sin , list(ones(100,100)) , 1 , 15 );
MY_assert_equal ( size(t) , [15 1] );
MY_assert_equal ( and(t>=0) , %t );
MY_assert_equal ( msg<>"" , %t );
//
[t,msg]=assert_benchfun ( sin , list(ones(100,100)) , 1 , 15 , "sin" );
MY_assert_equal ( size(t) , [15 1] );
MY_assert_equal ( and(t>=0) , %t );
MY_assert_equal ( msg<>"" , %t );
//
// Cannot test this: the time varies from call to call
//[t,msg]=assert_benchfun ( sin , list(ones(100,100)) , 1 , 15 , "sin" , %t );
[t,msg]=assert_benchfun ( sin , list(ones(100,100)) , 1 , 15 , "sin" , %f );
MY_assert_equal ( size(t) , [15 1] );
MY_assert_equal ( and(t>=0) , %t );
MY_assert_equal ( msg<>"" , %t );

